@@ -26,6 +26,7 @@ from majormode.perseus.constant.logging import LOGGING_LEVEL_LITERAL_STRINGS
 from majormode.perseus.constant.logging import LoggingLevelLiteral
 from majormode.perseus.utils.logging import cast_string_to_logging_level
 
+from bootloader.unreal_engine.model.apple_version import AppleAppVersion
 from bootloader.unreal_engine.utils import project_version
 from bootloader.unreal_engine.utils.project_version import DEFAULT_VERSION
 
@@ -76,12 +77,13 @@ def parse_arguments() -> argparse.Namespace:
     )
 
     parser.add_argument(
-        '--update-version',
-        action='store_true',
-        dest='update_version',
+        '--logging-level',
+        dest='logging_level',
+        metavar='LEVEL',
         required=False,
-        help="indicate whether to update the defined in the Unreal Engine project. "
-             "This argument MUST be used with the argument `--build-number`."
+        default=str(LoggingLevelLiteral.info),
+        type=cast_string_to_logging_level,
+        help=f"specify the logging level ({', '.join(LOGGING_LEVEL_LITERAL_STRINGS)})"
     )
 
     parser.add_argument(
@@ -94,13 +96,22 @@ def parse_arguments() -> argparse.Namespace:
     )
 
     parser.add_argument(
-        '--logging-level',
-        dest='logging_level',
-        metavar='LEVEL',
+        '--replace-patch-version',
+        action='store_true',
+        dest='replace_patch_version',
         required=False,
-        default=str(LoggingLevelLiteral.info),
-        type=cast_string_to_logging_level,
-        help=f"specify the logging level ({', '.join(LOGGING_LEVEL_LITERAL_STRINGS)})"
+        help="indicate whether to replace the patch version of the Unreal Engine "
+             "project with the specified build number.  This argument MUST be used "
+             "with the argument `--build-number`."
+    )
+
+    parser.add_argument(
+        '--update-version',
+        action='store_true',
+        dest='update_version',
+        required=False,
+        help="indicate whether to update the defined in the Unreal Engine project. "
+             "This argument MUST be used with the argument `--build-number`."
     )
 
     return parser.parse_args()
@@ -111,14 +122,18 @@ def run():
 
     setup_logger(logging_formatter=DEFAULT_LOGGING_FORMATTER, logging_level=arguments.logging_level)
 
-    version = project_version.find_project_version_ini_file(arguments.path, require_semantic_versioning=True)
+    version = project_version.read_project_version(
+        arguments.path,
+        build_number=arguments.build_number,
+        replace_patch_version=arguments.replace_patch_version,
+        require_semantic_versioning=True)
 
-    if arguments.build_number:
-        version = f'{version}+{arguments.build_number}'
-        if arguments.update_version:
-            project_version.update_project_version_ini_file(arguments.path, version)
+    if arguments.update_version:
+        project_version.update_project_version(arguments.path, version)
+        ios_version = AppleAppVersion(version, arguments.build_number or 0)
+        project_version.update_ios_version(arguments.path, ios_version)
 
-    print(version)
+    print(f'{version}+{arguments.build_number}' if arguments else version)
 
 
 def setup_logger(
